<!--
SPDX-FileCopyrightText: 2023 Helge

SPDX-License-Identifier: MIT
-->

# Changes to bovine_process

Version 0.5.1

- Rafactor `bovine_propan` handling add tests in `tests/test_rabbit.py`

Version 0.4.0

- Include package bovine_propan for AQMP based Activity handling
